import React from 'react'
import { commonSettings, switchSettings, elementSettings } from './otherSettings'
import {
  GroupOutlined,
  EditOutlined,
  FormOutlined,
  FieldBinaryOutlined,
  HighlightOutlined,
  FieldTimeOutlined,
  LinkOutlined,
} from '@ant-design/icons'

const allSetting = {
  ...commonSettings,
  ...switchSettings,
  ...elementSettings
}

const base = {
  groupBase: {
    title: '基础信息',
    type: 'object',
    properties: {}
  },
  $id: {
    title: '字段名称',
    type: 'string',
    widget: 'FieldNames',
    required: true,
    displayType: 'row',
    labelWidth: 80,
  },
  title: {
    title: '标题',
    required: true,
    type: 'string',
    widget: 'htmlInput',
    displayType: 'row',
    labelWidth: 80,
  },
  placeholder: {
    title: '提示语',
    type: 'string',
    // widget: 'Placeholder',
    displayType: 'row',
    labelWidth: 80,
    // dependencies: ['title']
  },
  presetValue: {
    title: '默认值',
    type: 'string',
    widget: 'InputDefault',
    displayType: 'row',
    labelWidth: 80,
  },
}

const groupStyle = {
  groupStyle: {
    title: '控件样式',
    type: 'object',
    properties: {}
  },
  width: {
    title: '元素宽度',
    type: 'string',
    widget: 'percentSlider',
  },
  labelWidth: {
    title: '标签宽度',
    description: '默认值110',
    default: 110,
    type: 'number',
    widget: 'slider',
    max: 400,
    props: {
      hideNumber: true,
    },
  },
}

const layoutWidgets = [
  {
    text: '分组名称',
    name: '分组名称',
    icon: <GroupOutlined />,
    schema: {
      title: '分组名称',
      type: 'object',
      collapsed: true,
      // theme: 'collapse:pure',
      // properties: {
      //   title: {
      //     title: '标题',
      //     type: 'string',
      //     required: true,
      //     displayType: 'row',
      //     labelWidth: 80,
      //   },
      // },
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      title: {
        title: '标题',
        type: 'string',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
    },
  },
]

const textWidgets = [
  {
    text: '文本',
    name: '文本',
    icon: <EditOutlined />,
    schema: {
      title: '文本',
      type: 'string',
      widget: 'TextInput',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        collapsed: true,
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        tableName: "{{console.log('1',rootValue)}}",
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        // widget: 'Placeholder',
        displayType: 'row',
        labelWidth: 80,
        // dependencies: ['title']
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'InputDefault',
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 100,
      },
      maxLength: {
        title: '字节最大长度',
        type: 'number',
        widget: 'number',
        default: 200,
        displayType: 'row',
        labelWidth: 100,
      },
      rules: {
        title: '正则校验',
        type: 'array',
        default: [],
        widget: 'VerifyTextInput',
        displayType: 'row',
        labelWidth: 100,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      emphasis: {
        title: '强调',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      addonBefore: {
        title: '前置标签',
        type: 'string',
        widget: 'InputAddon',
        displayType: 'row',
        labelWidth: 80,
      },
      addonAfter: {
        title: '后置标签',
        type: 'string',
        widget: 'InputAddon',
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
        // default: '100%',
      },
      displayType: {
        title: '标签展示模式',
        type: 'string',
        default: 'row',
        enum: ['row', 'column'],
        enumNames: ['同行', '单独一行'],
        widget: 'select',
        displayType: 'row',
        labelWidth: 100,
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '多行文本',
    name: '多行文本',
    icon: <FormOutlined />,
    schema: {
      title: '多行文本',
      type: 'string',
      widget: 'TextArea'
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        // widget: 'Placeholder',
        displayType: 'row',
        labelWidth: 80,
        // dependencies: ['title']
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 100,
      },
      maxLength: {
        title: '最大长度',
        type: 'number',
        widget: 'number',
        default: 500,
        displayType: 'row',
        labelWidth: 100,
        description: '可输入最大字节长度'
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      emphasis: {
        title: '强调',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      rows: {
        title: '高度',
        description: '多行文本占据的行数',
        type: 'number',
        widget: 'number',
        max: 10,
        default: 5,
        widget: 'slider',
        props: {
          hideNumber: true,
        },
      },
      width: {
        title: '元素宽度',
        description: '默认值100%',
        type: 'string',
        widget: 'percentSlider',
        default: '100%',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '数值',
    name: '数值',
    icon: <FieldBinaryOutlined />,
    schema: {
      title: '数值',
      type: 'number',
      widget: 'NumberInput',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        // widget: 'Placeholder',
        displayType: 'row',
        labelWidth: 80,
        // dependencies: ['title']
      },
      presetValue: {
        title: '默认值',
        type: 'number',
        widget: 'NumerDefault',
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 70,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      emphasis: {
        title: '强调',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      prefix: {
        title: '前缀',
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 60,
      },
      formatter: {
        title: '格式化',
        type: 'string',
        displayType: 'row',
        labelWidth: 60,
        widget: 'select',
        enum: ['%', '‰'],
        default: '',
        enumNames: ['%', '‰'],
        props: {
          allowClear: true
        }
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '富文本',
    name: '富文本',
    icon: <HighlightOutlined />,
    schema: {
      title: '富文本',
      name: '富文本',
      type: 'string',
      widget: 'RichText',
      width: '100%',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      // placeholder: {
      //   title: '提示语',
      //   type: 'string',
      //   // widget: 'Placeholder',
      //   displayType: 'row',
      //   labelWidth: 80,
      //   // dependencies: ['title']
      // },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      emphasis: {
        title: '强调',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      ...groupStyle,
    },
  },
]

const selectWidgets = [
  {
    text: '选择器',
    name: '选择器',
    schema: {
      title: '选择器',
      name: '选择器',
      type: 'string',
      widget: 'ValueSelect',
      require: true,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        collapsed: true,
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        // widget: 'Placeholder',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      gorupSoruce: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      soruceType: {
        title: '来源方式',
        name: '来源方式',
        type: 'string',
        widget: 'select',
        default: '手动输入',
        enum: ['手动输入', '数据字典'],
        enumNames: ['手动输入', '数据字典'],
        displayType: 'row',
        labelWidth: 80,
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        hidden: '{{formData.soruceType !== "手动输入"}}',
        default: [],
        widget: 'simpleList',
        default: [
          { value: '选项一', },
        ],
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
        displayType: 'row',
        labelWidth: 80,
      },
      dictionary: {
        title: '数据字典',
        name: '数据字典',
        type: 'string',
        widget: 'Dictionary',
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 70,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      emphasis: {
        title: '强调',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isEdit: {
        title: '是否可编辑',
        type: 'boolean',
        widget: 'BooleanSwitch',
        displayType: 'row',
        labelWidth: 120,
        description: '勾选后可直接输入选项'
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      showType: {
        title: '显示方式',
        type: 'string',
        enum: ['下拉', '平铺'],
        default: '下拉',
        enumNames: ['下拉', '平铺'],
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '树选择',
    name: '树选择',
    schema: {
      title: '树选择',
      name: '树选择',
      type: 'string',
      widget: 'ValueSelect',
      require: true,
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        collapsed: true,
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        // widget: 'Placeholder',
        displayType: 'row',
        labelWidth: 80,
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      gorupSoruce: {
        title: '数据来源',
        type: 'object',
        properties: {}
      },
      options: {
        title: '选项',
        name: '选项',
        type: 'array',
        default: [],
        widget: 'simpleList',
        default: [
          { value: '选项一', },
        ],
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
        displayType: 'row',
        labelWidth: 80,
      },
      groupVerify: {
        title: '数据校验',
        type: 'object',
        properties: {}
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 70,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      emphasis: {
        title: '强调',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isEdit: {
        title: '是否可编辑',
        type: 'boolean',
        widget: 'BooleanSwitch',
        displayType: 'row',
        labelWidth: 120,
        description: '勾选后可直接输入选项'
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      showType: {
        title: '显示方式',
        type: 'string',
        enum: ['下拉', '平铺'],
        default: '下拉',
        enumNames: ['下拉', '平铺'],
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '关联选择',
    name: '关联选择',
    schema: {
      title: '关联选择器',
      name: '关联选择器',
      type: 'string',
      widget: 'CascadeSelect',
      require: true,
    },
    setting: {
      ...commonSettings,
      dependencies: {
        title: '关联字段',
        type: 'array',
        widget: 'CascadeField',
        displayType: 'row',
        labelWidth: 80,
      },
      // isMultiple: {
      //   title: '是否多选',
      //   type: 'boolean',
      //   widget: 'BooleanSwitch',
      //   displayType: 'row',
      //   labelWidth: 80,
      // },
      ...switchSettings,
      ...elementSettings,
    }
  },
  {
    text: '人员选择器',
    name: '人员选择器',
    schema: {
      title: '人员选择器',
      name: '人员选择器',
      type: 'string',
      widget: 'PersonSelect',
      require: true,
    },
    setting: {
      ...commonSettings,
      // dependencies: {
      //   title: '关联字段',
      //   type: 'array',
      //   widget: 'CascadeField',
      //   displayType: 'row',
      //   labelWidth: 80,
      // },
      // isMultiple: {
      //   title: '是否多选',
      //   type: 'boolean',
      //   widget: 'BooleanSwitch',
      //   displayType: 'row',
      //   labelWidth: 80,
      // },
      ...switchSettings,
      ...elementSettings,
    }
  },
]

const fileWidgets = [
  {
    text: '附件',
    name: '附件',
    icon: <LinkOutlined />,
    schema: {
      title: '附件',
      type: 'string',
      widget: 'FileUpload',
      width: '100%'
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      $id: {
        title: '字段名称',
        type: 'string',
        widget: 'FieldNames',
        required: true,
        displayType: 'row',
        labelWidth: 80,
      },
      title: {
        title: '标题',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        displayType: 'row',
        labelWidth: 80,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
      },
      groupSetting: {
        title: '控件设置',
        type: 'object',
        properties: {}
      },
      fileType: {
        title: '文件类型',
        type: 'string',
        required: true,
        widget: 'select',
        enum: ['全部', '图片', '文档', '音频', '视频'],
        enumNames: ['全部', '图片', '文档', '音频', '视频'],
        default: '全部',
        displayType: 'row',
        labelWidth: 80,
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      hidden: {
        title: '隐藏',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      preview: {
        title: '预览',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '33%',
      },
      download: {
        title: '下载',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '33%',
      },
      photo: {
        title: '允许从相册选取',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        hidden: "{{formData.fileType !== '图片'}}"
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      showType: {
        title: '显示方式',
        type: 'string',
        default: 'picture',
        enum: ['picture', 'text', 'picture-card'],
        enumNames: ['列表_详细', '列表_省略', '卡片'],
      },
      // width: {
      //   title: '元素宽度',
      //   type: 'string',
      //   widget: 'percentSlider',
      //   default: '100%',
      // },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
]

const settings = [
  {
    title: '布局控件',
    widgets: layoutWidgets
  },
  {
    title: '文本控件',
    widgets: textWidgets
  },
  {
    title: '选择器控件',
    widgets: selectWidgets,
  },
  {
    title: '时间控件',
    show: true,
    useCommon: true,
    widgets: [
      {
        text: '日期选择',
        name: '日期选择',
        schema: {
          title: '日期选择',
          type: 'string',
          widget: 'DateTime',
        },
        setting: {
          ...commonSettings,
          presetValue: {
            title: '默认值',
            type: 'string',
            displayType: 'row',
            labelWidth: 80,
            widget: 'DateSelect',
            dependencies: ['format']
          },
          format: {
            title: '日期格式',
            type: 'string',
            // enum: ['date', 'dateTime', 'year', 'month', 'quarter', 'week'],
            enum: ['date', 'dateTime', 'year', 'month'],
            default: 'date',
            enumNames: ['日期', '日期时间', '日期年份', '日期月份'],
            displayType: 'row',
            labelWidth: 80,
          },
          ...switchSettings,
          ...elementSettings,
        },
      },
      {
        text: '时间选择',
        name: '时间选择',
        icon: <FieldTimeOutlined />,
        schema: {
          title: '时间选择',
          type: 'string',
          widget: 'Time',
          format: 'time',
        },
        setting: {
          ...commonSettings,
          presetValue: {
            title: '默认值',
            type: 'string',
            widget: 'time',
            format: 'time',
            displayType: 'row',
            labelWidth: 80,
          },
          ...switchSettings,
          ...elementSettings,
        },
      },
    ],
  },
  {
    title: '附件控件',
    show: true,
    useCommon: true,
    widgets: fileWidgets,
  },
  {
    title: '地图控件',
    show: true,
    useCommon: true,
    widgets: [
      {
        text: '坐标控件',
        name: '坐标控件',
        schema: {
          title: '坐标控件',
          type: 'string',
          widget: 'Coordinate',
        },
      },
    ],
  },
  {
    title: '高级控件',
    widgets: [
      {
        text: '关联表单',
        name: '关联表单',
        schema: {
          title: '关联表单',
          name: '关联表单',
          type: 'string',
          widget: 'RelationForm',
          width: '100%',
        },
        setting: {
          $id: {
            title: '字段名称',
            type: 'string',
            widget: 'FieldNames',
            required: true,
            displayType: 'row',
            labelWidth: 80,
          },
          title: {
            title: '标题',
            type: 'string',
            widget: 'htmlInput',
            displayType: 'row',
            labelWidth: 80,
          },
          source: {
            title: '数据来源',
            type: 'string',
            displayType: 'row',
            default: '{}',
            widget: 'DataSource',
            labelWidth: 80,
          },
          disabled: {
            title: '只读',
            type: 'boolean',
            widget: 'BooleanSwitch',
            displayType: 'row',
            labelWidth: 80,
            default: false
          },
          width: {
            title: '元素宽度',
            type: 'string',
            widget: 'percentSlider',
            // default: '100%',
          },
          ...elementSettings,
        },
      },
    ],
  },
]

export default settings